﻿using Microsoft.AspNetCore.Mvc;
using ReportingServices.Shared.HelperClasses;
using ReportingServices.Shared.Models.ProductionReport;
using ReportingServices.Shared.ViewModels.ProductionReport;

namespace ReportingServices.UI.Controllers
{
    public class ProductionReportController : Controller
    {
        private readonly ILogger<ProductionReportController> _logger;
        private readonly string _dailyRptFilePath = "wwwroot/Assets/DailyReportInfo.json";
        private readonly string _toolStateOwnerFilePath = "wwwroot/Assets/ToolStates.json";
        private readonly string _baseFTUrl;
        private readonly string _baseDBUrl;

        public ProductionReportController(ILogger<ProductionReportController> logger)
        {
            _logger = logger;
            _baseFTUrl = "http://mestsa008:50201/api/";
            _baseDBUrl = "http://localhost:50201/api/"; 

            _logger.LogInformation("Base FabTime Address: {baseUrl}", _baseFTUrl);
            _logger.LogInformation("Base Database Address: {baseUrl}", _baseDBUrl);
        }


        public IActionResult Index()
        {
            return View();
        }

        public IActionResult DailyReport()
        {
            string baseFabTimeUrl = _baseFTUrl + "FabTime/";
            string baseScrapeDbUrl = _baseDBUrl + "ScrapeDB/";

            try
            {
                DailyReport dailyReport = DailyReportHelper.SetUpDailyReport(_logger, baseFabTimeUrl, baseScrapeDbUrl);
                Dictionary<string, List<string>> toolStateOwners = JsonFileHandler.LoadJSONFile<Dictionary<string, List<string>>>(_toolStateOwnerFilePath);

                dailyReport.ToolStatesByOwner = toolStateOwners;

                return View(dailyReport);
            }
            catch (Exception ex)
            {
                _logger.LogCritical(ex, "Failed to load report");
                return View();
            }
        }

        public IActionResult EditDailyReport()
        {
            ManualReportEntries entries = JsonFileHandler.LoadJSONFile<ManualReportEntries>(_dailyRptFilePath);

            return View(entries);
        }

        [HttpPost]
        public IActionResult EditDailyReport(ManualReportEntries rpt)
        {
            JsonFileHandler.SaveJSONFile(rpt, _dailyRptFilePath);

            return RedirectToAction("DailyReport");
        }
    }
}
